// Type definition for exam questions that matches the Quiz component's expected format
export interface ExamQuestion {
  qid: string;
  question: string;
  correct_answer: string;
  explanation: string;
  image_url: string; // Required in QuizQuestion
  suggestion: string[];
  audio_url?: string;
}

/**
 * Client-safe function to load exam questions from the API
 * @param examNumber The exam number to load (1, 2, 3, etc.)
 * @returns An array of exam questions
 */
export async function loadExamQuestions(examNumber: number): Promise<ExamQuestion[]> {
  try {
    // Use the API to fetch exam data instead of direct file access
    const response = await fetch(`/api/exams/${examNumber}`);
    
    if (!response.ok) {
      throw new Error(`Failed to load exam ${examNumber}: ${response.status} ${response.statusText}`);
    }
    
    const data = await response.json();
    return data.questions;
  } catch (error) {
    console.error(`Error loading exam ${examNumber}:`, error);
    // Fallback to an empty array if there's an error
    return [];
  }
}
